@@ -672,6 +672,14 @@ class DataSource2D(QtCore.QObject):
         else:
             return self._device_proxy.is_running()
 
+    # ----------------------------------------------------------------------
+    def get_camera_type(self):
+        """
+
+        :return: bool
+        """
+        return self._device_proxy.__class__.__name__
+
     # ----------------------------------------------------------------------
     def has_motor(self):
         """
